@@ -26,29 +26,28 @@
 #include <gnuradio/zeromq/pub_sink.h>
 #include <zmq.hpp>
 
+#include "base_impl.h"
+
 namespace gr {
-  namespace zeromq {
+namespace zeromq {
 
-    class pub_sink_impl : public pub_sink
-    {
-    private:
-      size_t          d_itemsize;
-      size_t          d_vlen;
-      float           d_timeout;
-      zmq::context_t  *d_context;
-      zmq::socket_t   *d_socket;
-      bool            d_pass_tags;
+class pub_sink_impl : public pub_sink, public base_sink_impl
+{
+public:
+    pub_sink_impl(size_t itemsize,
+                  size_t vlen,
+                  char* address,
+                  int timeout,
+                  bool pass_tags,
+                  int hwm);
 
-    public:
-      pub_sink_impl(size_t itemsize, size_t vlen, char *address, int timeout, bool pass_tags);
-      ~pub_sink_impl();
+    int work(int noutput_items,
+             gr_vector_const_void_star& input_items,
+             gr_vector_void_star& output_items);
+    std::string last_endpoint() override { return base_sink_impl::last_endpoint(); }
+};
 
-      int work(int noutput_items,
-               gr_vector_const_void_star &input_items,
-               gr_vector_void_star &output_items);
-    };
-
-  } // namespace zeromq
+} // namespace zeromq
 } // namespace gr
 
 #endif /* INCLUDED_ZEROMQ_PUB_SINK_IMPL_H */
