@@ -26,29 +26,32 @@
 #include <gnuradio/zeromq/req_source.h>
 #include <zmq.hpp>
 
+#include "base_impl.h"
+
 namespace gr {
-  namespace zeromq {
+namespace zeromq {
 
-    class req_source_impl : public req_source
-    {
-    private:
-      size_t          d_itemsize;
-      size_t          d_vlen;
-      int             d_timeout;
-      zmq::context_t  *d_context;
-      zmq::socket_t   *d_socket;
-      bool            d_pass_tags;
+class req_source_impl : public req_source, public base_source_impl
+{
+public:
+    req_source_impl(size_t itemsize,
+                    size_t vlen,
+                    char* address,
+                    int timeout,
+                    bool pass_tags,
+                    int hwm);
 
-    public:
-      req_source_impl(size_t itemsize, size_t vlen, char *address, int timeout, bool pass_tags);
-      ~req_source_impl();
+    int work(int noutput_items,
+             gr_vector_const_void_star& input_items,
+             gr_vector_void_star& output_items);
 
-      int work(int noutput_items,
-               gr_vector_const_void_star &input_items,
-               gr_vector_void_star &output_items);
-    };
+    std::string last_endpoint() override { return base_source_impl::last_endpoint(); }
 
-  } // namespace zeromq
+private:
+    bool d_req_pending;
+};
+
+} // namespace zeromq
 } // namespace gr
 
 #endif /* INCLUDED_ZEROMQ_REQ_SOURCE_IMPL_H */
